==> download.php?fname=cb_web_3.0.4_ioncube_72.zip: cb/modules/clientbase/wazzup/assets/locale.js <==
export const localeEn = {
  "api_tab": "Api",
  "channels_tab": "Channels",
  "access_tab": "Access rights",
  "Save": "Save",
  "settings_saved": "The settings have been saved successfully.",
  "settings_not_saved": "Problem saving settings.",

  // API
  "personal_account": "Register an API key",
  "module_activated": "Module activated",
  "module_not_activated": "Module not activated",
  "api_key": "Api key",

  // Access
  "access_groups": "Access groups",
  "Users": "Users",
  "User": "User",
  "cb_user": "CB user",
  "wazzup_user": "Wazzup user",
  "no_set": "no set",
  "no_name": "No name",
  "add_user": "Add user",
  "username": "Username",

  // Channels
  "need_to_add_channels": "You need to add channels in your wazzup account.",
  "channel_id": "Channel id",
  "channel_name": "Channel name",
  "add_table": "Add table",
  "Table": "Table",
  "nickname_field": "Nickname field",
  "phone_field": "Phone field",
  "priority": "A priority",
  "low": "low",
  "medium": "medium",
  "high": "high",
  "filter": "Filter",
  "create_new_entry": "Create a new entry",
  "client_name_field_label": "Name/Full name",
  "responsible_manager_field_label": "Responsible Manager",

  // Additionally
  "additionally_tab": "Additionally",
  "default_channel_for_reminders": "Default channel for reminders",
  "maximum_number_of_messages_per_hour": "Maximum number of messages per hour",
  "": "",
}


export const localeRu = {
  "api_tab": "Api",
  "channels_tab": "Каналы",
  "access_tab": "Доступы",
  "Save": "Сохранить",
  "settings_saved": "Настройки успешно сохранены.",
  "settings_not_saved": "Проблема при сохранении настроек.",

  // API
  "personal_account": "Зарегистрировать ключ API",
  "module_activated": "Модуль активирован",
  "module_not_activated": "Модуль не активирован",
  "api_key": "Ключ API",

  // Access
  "access_groups": "Группы доступа",
  "Users": "Пользователи",
  "User": "Пользователь",
  "cb_user": "Пользователь КБ",
  "wazzup_user": "Пользователь wazzup",
  "no_set": "не задан",
  "no_name": "Без имени",
  "add_user": "Добавить пользователя",
  "username": "Имя пользователя",

  // Channels
  "need_to_add_channels": "Необходимо добавить каналы в личном кабинете wazzup.",
  "channel_id": "Идентификатор канала",
  "channel_name": "Название канала",
  "add_table": "Добавить таблицу",
  "Table": "Таблица",
  "nickname_field": "Поле никнейм",
  "phone_field": "Поле телефон",
  "priority": "Приоритет",
  "low": "низкий",
  "medium": "средний",
  "high": "высокий",
  "filter": "Фильтр",
  "create_new_entry": "Создать новую запись",
  "client_name_field_label": "Название/Фио",
  "responsible_manager_field_label": "Ответственный менеджер",

  // Additionally
  "additionally_tab": "Дополнительно",
  "default_channel_for_reminders": "Канал по умолчанию для напоминаний",
  "maximum_number_of_messages_per_hour": "Максимальное количество сообщений в час",
  "": "",
}

==> download.php?fname=cb_web_3.0.5_ioncube_72.zip: cb/modules/clientbase/wazzup/assets/locale.js <==
export const localeEn = {
  "api_tab": "Api",
  "channels_tab": "Channels",
  "access_tab": "Access rights",
  "Save": "Save",
  "settings_saved": "The settings have been saved successfully.",
  "settings_not_saved": "Problem saving settings.",

  // API
  "personal_account": "Register an API key",
  "module_activated": "Module activated",
  "module_not_activated": "Module not activated",
  "api_key": "Api key",

  // Access
  "access_groups": "Access groups",
  "Users": "Users",
  "User": "User",
  "cb_user": "CB user",
  "wazzup_user": "Wazzup user",
  "no_set": "no set",
  "no_name": "No name",
  "add_user": "Add user",
  "username": "Username",

  // Channels
  "need_to_add_channels": "You need to add channels in your wazzup account.",
  "channel_id": "Channel id",
  "channel_name": "Channel name",
  "add_table": "Add table",
  "Table": "Table",
  "nickname_field": "Nickname field",
  "phone_field": "Phone field",
  "priority": "A priority",
  "low": "low",
  "medium": "medium",
  "high": "high",
  "filter": "Filter",
  "create_new_entry": "Create a new entry",
  "client_name_field_label": "Name/Full name",
  "responsible_manager_field_label": "Responsible Manager",

  // Additionally
  "additionally_tab": "Additionally",
  "default_channel_for_reminders": "Default channel for reminders",
  "maximum_number_of_messages_per_hour": "Maximum number of messages per hour",
  "delete_days": "Delete message",
  "": "",
}


export const localeRu = {
  "api_tab": "Api",
  "channels_tab": "Каналы",
  "access_tab": "Доступы",
  "Save": "Сохранить",
  "settings_saved": "Настройки успешно сохранены.",
  "settings_not_saved": "Проблема при сохранении настроек.",

  // API
  "personal_account": "Зарегистрировать ключ API",
  "module_activated": "Модуль активирован",
  "module_not_activated": "Модуль не активирован",
  "api_key": "Ключ API",

  // Access
  "access_groups": "Группы доступа",
  "Users": "Пользователи",
  "User": "Пользователь",
  "cb_user": "Пользователь КБ",
  "wazzup_user": "Пользователь wazzup",
  "no_set": "не задан",
  "no_name": "Без имени",
  "add_user": "Добавить пользователя",
  "username": "Имя пользователя",

  // Channels
  "need_to_add_channels": "Необходимо добавить каналы в личном кабинете wazzup.",
  "channel_id": "Идентификатор канала",
  "channel_name": "Название канала",
  "add_table": "Добавить таблицу",
  "Table": "Таблица",
  "nickname_field": "Поле никнейм",
  "phone_field": "Поле телефон",
  "priority": "Приоритет",
  "low": "низкий",
  "medium": "средний",
  "high": "высокий",
  "filter": "Фильтр",
  "create_new_entry": "Создать новую запись",
  "client_name_field_label": "Название/Фио",
  "responsible_manager_field_label": "Ответственный менеджер",

  // Additionally
  "additionally_tab": "Дополнительно",
  "default_channel_for_reminders": "Канал по умолчанию для напоминаний",
  "maximum_number_of_messages_per_hour": "Максимальное количество сообщений в час",
  "delete_days": "Удалить сообщения старше",
  "wazzup_supervisor" : "Включить обработку Webhook через очередь (Supervisor)",
  "": "",
}
